Struct trillium_server_common::CloneCounter [−][src]
pub struct CloneCounter(_);
an atomic counter that increments on clone & decrements on drop
use futures_lite::future::poll_once; let counter = CloneCounter::new(); assert_eq!(counter.current(), 0); counter.await; // ready immediately let counter = CloneCounter::new(); assert_eq!(counter.current(), 0); let clone = counter.clone(); assert_eq!(counter.current(), 1); let clone2 = counter.clone(); assert_eq!(counter.current(), 2); assert_eq!(poll_once(clone2).await, None); // pending assert_eq!(counter.current(), 1); std::mem::drop(clone); assert_eq!(counter.current(), 0); counter.await; // ready
Implementations
Returns the current count. The first CloneCounter is zero, so this can either be considered a zero-indexed count of the total number of CloneCounters in memory, or a one-indexed count of the number of non-original clones.
Manually decrement the count. This is useful when taking a clone of the counter that does not represent an increase in the underlying property or resource being counted. This is called automatically on drop and is usually unnecessary to call directly